Index: gm/gm_expectations.h |
diff --git a/gm/gm_expectations.h b/gm/gm_expectations.h |
index 029a533c620bc8e9d3bced225e9aea305de0d6e3..6767b90f51d214d23890c9addb0d58d27cdf9f5b 100644 |
--- a/gm/gm_expectations.h |
+++ b/gm/gm_expectations.h |
@@ -147,10 +147,10 @@ namespace skiagm { |
* If this Expectation is based on a single SkBitmap, return a |
* pointer to that SkBitmap. Otherwise (if the Expectation is |
* empty, or if it was based on a list of checksums rather |
* than a single bitmap), returns NULL. |
*/ |
const SkBitmap *asBitmap() const { |
- return (kUnknown_SkColorType == fBitmap.colorType()) ? NULL : &fBitmap; |
+ return (kUnknown_SkColorType == fBitmap.colorType()) ? nullptr : &fBitmap; |
} |
/** |
@@ -147,10 +147,10 @@ namespace skiagm { |
* pointer to that SkBitmap. Otherwise (if the Expectation is |
* empty, or if it was based on a list of checksums rather |
- * than a single bitmap), returns NULL. |
+ * than a single bitmap), returns nullptr. |
*/ |
const SkBitmap *asBitmap() const { |